% Bias of beta (based on general estimating equation)

% In HN notation
% B = - H^{-1} b
% H = \mean_{i,t} u_{it,b} - u_{it,a} \sum_{s} v_{is,b} / \sum_{s} v_{is,a}
% b = \mean_{i,t} u_{it,a} (bias_alpha_{i} + phi_alpha_{it}) + (1/2)
% u_{it,aa} sigma2_alpha_{i}

function BIAS = bias_beta_tobit(y,x,d,n,index)

D = dummyvar(index);
t = mean(sum(D));
p = size(x,2)-n;

dy = real(y > 0);
h = d(1,1);
delta = d(2:size(d,1),1);
mu = x*delta;
lambdabar = mills_prob(-mu);

vit   = dy .* (h*y - mu) - (1 - dy) .* lambdabar ;
vita  = -dy + (1 - dy) .* dmills_prob(-mu);
vitaa = - (1 - dy) .* ddmills_prob(- mu);

uit   = [dy .* (1/h - (h*y - mu) .* y),   x(:,1:p) .* (vit*ones(1,p))];
uita  = [dy .* y,   x(:,1:p) .* (vita*ones(1,p))];
uitaa = [0*y,  x(:,1:p) .* (vitaa*ones(1,p))];


uitb  = [- sum(dy .* (1/(h^2) + y.^2)), (dy .* y)' * x(:,1:p);
            x(:,1:p)' * (dy .* y),  x(:,1:p)' * (x(:,1:p) .* (vita*ones(1,p)))];
vitb  = uita;

s_vita = kron(D'*vita,ones(t,1));
s_vitb = kron(D'*vitb,ones(t,1));

TEMP1 = s_vitb ./ (s_vita * ones(1,p+1));

H     = uitb - uita' * TEMP1;


pit   = phi_alpha_tobit(y,x,d,index);

pis = reshape(pit,t,n);
pis = [zeros(1,n) ; pis(1:(t-1),:)];
pis = (t/(t-1))*reshape(pis,t*n,1);

uisa = reshape(uita,t,n*(p+1));
uisa = [zeros(1,n*(p+1)) ; uisa(1:(t-1),:)];
uisa = (t/(t-1))*reshape(uisa,t*n,(p+1));

b     = sum(uita .* ((kron(bias_alpha_tobit(y,x,d,index),ones(t,1)) + phi_alpha_tobit(y,x,d,index) +  pis )*ones(1,p+1)) ...
     +  uisa .* (pit * ones(1,p+1)) + 1/2 * uitaa .* (kron(sigma2_alpha_tobit(y,x,d,index),ones(t,1)) * ones(1,p+1)),1)';


BIAS  = -inv(H)*b;

